@@ -1,11 +1,8 @@
-CONFIG_FILE = 'settings.ini'
+import os
 
-SPECIAL_KEYS = {
-	'alt': 'alt',
-	'tab': 'Tab',
-	'control': 'ctrl',
-	'delete': 'Delete',
-}
+CONFIG_PATH = os.path.join('usr', 'local', 'etc', 'config.ini')
+
+CONFIG_FILE = 'settings.ini'
 
 NUMBERS_MAP = {
 	'zero': '0',
@@ -26,26 +23,6 @@ NUMBERS_MAP = {
     'sex': '6',
 }
 
-
-XDOTOOL_MAP = {
-	' ': '0x0020',
-	'!': '0x0021',
-	'"': '0x0022',
-        '%': '0x0025',
-	"'": '0x0027',
-	'(': '0x0028',
-	')': '0x0029',
-	',': '0x002C',
-	'-': '0x002D',
-	'.': '0x002E',
-	':': '0x003A',
-	'\\': '0x005C',
-	'[': '0x005B',
-	']': '0x005D',
-	'_': '0x005F',
-	'^': '0x0AFC',
-}
-
 HOMONYMS = {
     'args': ['arcs', 'our', 'arts', 'arms', 'are', "arby's", 'earns', 'orange',
         'birds', 'outs', 'ours'],
